@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of HepMC
-// Copyright (C) 2014-2021 The HepMC collaboration (see AUTHORS for details)
+// Copyright (C) 2014-2023 The HepMC collaboration (see AUTHORS for details)
 //
 ///
 /// @file Feature.h
@@ -116,6 +116,14 @@ protected:
     /// Hide the copy constructor
     GenericFeature(const GenericFeature &copy) : m_internal(copy.m_internal) {}
 
+    /** @brief Move constructor */
+    GenericFeature(GenericFeature && ) = default;
+    /** @brief = */
+    GenericFeature& operator=(const GenericFeature&) = default;
+    /** @brief = */
+    GenericFeature& operator=(GenericFeature&&) = default;
+
+
     /// @brief internal copy of func for evaluation
     /// on the heap so will persist in resulting Filters even if
     /// parent Feature object was destroyed
@@ -177,6 +185,12 @@ public:
     Feature(Evaluator_type functor) : GenericFeature<Feature_type>(functor) {}
     /// @brief  Copy
     Feature(const Feature &copy) : GenericFeature<Feature_type>(copy) {}
+    /** @brief Move constructor */
+    Feature(Feature && ) = default;
+    /** @brief = */
+    Feature& operator=(const Feature&) = default;
+    /** @brief = */
+    Feature& operator=(Feature&&) = default;
 
     /// @brief  Abs function
     Feature<Feature_type> abs() const {
@@ -221,6 +235,13 @@ public:
     Feature(Evaluator_type functor) : GenericFeature<Feature_type>(functor) {}
     /// @brief  Feature
     Feature(const Feature &copy) : GenericFeature<Feature_type>(copy) {}
+    /** @brief Move constructor */
+    Feature(Feature && ) = default;
+    /** @brief = */
+    Feature& operator=(const Feature&) = default;
+    /** @brief = */
+    Feature& operator=(Feature&&) = default;
+
 
     /// @brief abs function
     Feature<Feature_type> abs() const {
@@ -290,6 +311,14 @@ public:
     /// @brief Copy
     Feature(const Feature &copy) : GenericFeature<Feature_type>(copy) {}
 
+    /** @brief Move constructor */
+    Feature(Feature && ) = default;
+    /** @brief = */
+    Feature& operator=(const Feature&) = default;
+    /** @brief = */
+    Feature& operator=(Feature&&) = default;
+
+
     /// @brief abs function
     Feature<Feature_type> abs() const {
         EvaluatorPtr functor = m_internal;
