@@ -81,7 +81,7 @@ private:
     void set_buffer_size(const size_t& size );
 
     /// @brief Escape '\' and '\n' characters in string
-    std::string escape(const std::string& s)  const;
+    static std::string escape(const std::string& s);
 
     /// Inline function flushing buffer to output stream when close to buffer capacity
     void flush();
@@ -116,13 +116,13 @@ private:
 private:
 
     std::ofstream m_file; //!< Output file
-    std::shared_ptr<std::ostream> m_shared_stream;///< Output temp. stream
-    std::ostream* m_stream; //!< Output stream
+    std::shared_ptr<std::ostream> m_shared_stream  = nullptr;///< Output temp. stream
+    std::ostream* m_stream = nullptr; //!< Output stream
 
-    int m_precision; //!< Output precision
-    char* m_buffer;  //!< Stream buffer
-    char* m_cursor;  //!< Cursor inside stream buffer
-    unsigned long m_buffer_size; //!< Buffer size
+    int m_precision = 16; //!< Output precision
+    char* m_buffer = nullptr;  //!< Stream buffer
+    char* m_cursor = nullptr;  //!< Cursor inside stream buffer
+    unsigned long m_buffer_size = 262144; //!< Buffer size
     std::string m_float_printf_specifier; //!< the specifier of printf used for floats
     std::string m_particle_printf_specifier; //!< the specifier of printf used for floats
     std::string m_vertex_short_printf_specifier; //!< the specifier of printf used for zero vertices
